spannertools.get_beam_spanner_attached_to_component
===================================================

.. autofunction:: abjad.tools.spannertools.get_beam_spanner_attached_to_component.get_beam_spanner_attached_to_component
